@@ -113,6 +113,20 @@ app_server <- function( input, output, session ) {
   edge_color          <- callModule(mod_server_choose_color_sd_palette, id = "mod_edge_colors")
 
   
+  
+
+  
+  ## Update selected elements_of_interest based on mineral composition selection -----------------------------
+  observeEvent(input$focal_from_mineral,{
+    
+    shinyWidgets::updatePickerInput(session = session,
+                                    "elements_of_interest", 
+                                    selected = get_focal_from_minerals(input$focal_from_mineral, med()$med_data)
+    ) 
+    
+    
+  }, ignoreNULL = FALSE)
+  
   ################################# Build network ####################################
   ## Construct the network from user input ------------------------------------------
   chemistry_network <- reactive({
@@ -124,9 +138,11 @@ app_server <- function( input, output, session ) {
     
     elements_of_interest <- input$elements_of_interest
     force_all_elements   <- input$force_all_elements
+    restrict_to_elements <- input$restrict_to_elements
     age_range            <- as.numeric(sort(input$age_range))  ## REVERSED, so sort here
     max_age_type         <- input$max_age_type
     elements_by_redox    <- input$elements_by_redox
+    ignore_na_redox      <- input$ignore_na_redox
     build_only           <- input$build_only
 
     
@@ -141,7 +157,7 @@ app_server <- function( input, output, session ) {
         text = "Networks with all elements, especially at more recent time frames, may be very slow - please be patient."
       )
     }
-    elements_only <- initialize_data(med()$med_data, med()$element_redox_states, elements_of_interest, force_all_elements)
+    elements_only <- initialize_data(med()$med_data, med()$element_redox_states, elements_of_interest, force_all_elements, restrict_to_elements)
     if (nrow(elements_only) == 0)
     {
       shinyWidgets::sendSweetAlert(
@@ -162,7 +178,7 @@ app_server <- function( input, output, session ) {
       shiny::validate( shiny::need(nrow(elements_only_age) > 0, ""))
     }
   
-    network <- construct_network(elements_only_age, elements_by_redox, med()$element_redox_states)
+    network <- construct_network(elements_only_age, elements_by_redox, ignore_na_redox, med()$element_redox_states)
     if (length(network) != 3 | nrow(network$nodes) == 0  | nrow(network$edges) == 0)
     {
       shinyWidgets::sendSweetAlert(
@@ -341,7 +357,7 @@ app_server <- function( input, output, session ) {
     })    
     
     output$connectivity <- renderText({
-      if (network_quantities()$connectivity == 0){
+      if (!(network_quantities()$connectivity)){
         paste0("WARNING: This network is disconnected. Interpret network metrics with caution.")
       }
       else {
